@@ -40,12 +40,12 @@ class Battery:
 
     def __init__(self, batinfo):
         self.bat = batinfo
-        self.normalize_µ()
+        self.normalize_micro()
 
-    def normalize_µ(self):
-        for key, µvalue in self.bat.items():
+    def normalize_micro(self):
+        for key, microvalue in self.bat.items():
             if re.match(r"(VOLTAGE|CHARGE|CURRENT|POWER|ENERGY)_(NOW|FULL|MIN)(_DESIGN)?", key):
-                self.bat[key] = float(µvalue) / 1000000.0
+                self.bat[key] = float(microvalue) / 1000000.0
 
     def percentage(self, design=False):
         return self._percentage("_DESIGN" if design else "") * 100
@@ -91,11 +91,11 @@ class BatteryEnergy(Battery):
 
 class BatteryChecker(IntervalModule):
 
-    """ 
+    """
     This class uses the /sys/class/power_supply/…/uevent interface to check for the
     battery status
 
-    Available formatters for format and alert_format_\*:
+    Available formatters:
 
     * `{remaining}` — remaining time for charging or discharging, uses TimeWrapper formatting, default format is `%E%h:%M`
     * `{percentage}` — battery percentage relative to the last full value
@@ -128,7 +128,7 @@ class BatteryChecker(IntervalModule):
     alert = False
     alert_percentage = 10
     alert_format_title = "Low battery"
-    alert_format_body = "Battery {battery_ident} has only {percentage:.2f}% ({remaining_hm}) remaining!"
+    alert_format_body = "Battery {battery_ident} has only {percentage:.2f}% ({remaining:%E%hh:%Mm}) remaining!"
 
     path = None
 
@@ -171,6 +171,7 @@ class BatteryChecker(IntervalModule):
                 body=formatp(self.alert_format_body, **fdict),
                 icon="battery-caution",
                 urgency=2,
+                timeout=60,
             )
 
         fdict["status"] = self.status[fdict["status"]]
