@@ -1,9 +1,22 @@
 
+
+def display_notification(title, body, icon="dialog-information", urgency=1, timeout=0):
+    """
+    Displays a desktop notification
+
+    :param title: Title of the notification
+    :param body: Body text of the notification, depending on the users system configuration HTML may be used, but is not recommended
+    :param icon: A XDG icon name, see http://standards.freedesktop.org/icon-naming-spec/icon-naming-spec-latest.html
+    :param urgency: A value between 1 and 3 with 1 meaning low urgency and 3 high urgency.
+    :param timeout: Timeout in seconds for the notification. Zero means it needs to be dismissed by the user.
+    :returns: boolean indicating success
+    """
+    return False
+
 try:
     from gi.repository import Notify
 except ImportError:
-    def display_notification(title, body, icon, urgency, timeout):
-        pass
+    pass
 else:
     if not Notify.init("i3pystatus"):
         raise ImportError("Couldn't initialize libnotify")
@@ -24,22 +37,3 @@ else:
             notification.set_timeout(timeout)
         notification.set_urgency(URGENCY_LUT[urgency])
         return notification.show()
-
-
-try:
-    from PyQt4 import Qt
-
-    app = Qt.QApplication([])
-
-    def display_menu(menu_items, x, y):
-        menu = Qt.QMenu()
-
-        for label, callable in menu_items:
-            action = menu.addAction(label)
-            action.triggered.connect(callable)
-
-        menu.popup(Qt.QPoint(x, y))
-        menu.exec_()
-except ImportError:
-    def display_menu(menu_items, x, y):
-        pass
