@@ -1,7 +1,9 @@
 
 import collections
+import functools
 import itertools
 import re
+import socket
 import string
 
 from i3pystatus.core.exceptions import *
@@ -9,6 +11,8 @@ from i3pystatus.core.imputil import ClassFinder
 
 
 def chain(fun):
+    """Method decorator to implicitly return `self` from the decorated method
+    """
     def chained(self, *args, **kwargs):
         fun(self, *args, **kwargs)
         return self
@@ -16,12 +20,24 @@ def chain(fun):
 
 
 def lchop(string, prefix):
+    """Removes a prefix from string
+
+    :param string: String, possibly prefixed with prefix
+    :param prefix: Prefix to remove from string
+    :returns: string without the prefix
+    """
     if string.startswith(prefix):
         return string[len(prefix):]
     return string
 
 
 def popwhile(predicate, iterable):
+    """Generator function yielding items of iterable while predicate holds for each item
+
+    :param predicate: function taking an item returning bool
+    :param iterable: iterable
+    :returns: iterable (generator function)
+    """
     while iterable:
         item = iterable.pop()
         if predicate(item):
@@ -46,12 +62,14 @@ def partition(iterable, limit, key=lambda x: x):
 
 
 def round_dict(dic, places):
+    """
+    Rounds all values in a dict containing only numeric types to `places` decimal places.
+    """
     for key, value in dic.items():
         dic[key] = round(value, places)
 
 
 class ModuleList(collections.UserList):
-
     def __init__(self, status_handler, module_base):
         self.status_handler = status_handler
         self.finder = ClassFinder(module_base)
@@ -73,6 +91,11 @@ class ModuleList(collections.UserList):
 
 
 class PrefixedKeyDict(collections.UserDict):
+    """
+    A dict implementation adding a prefix to every key added
+
+    :param prefix: Prefix to prepend
+    """
 
     def __init__(self, prefix):
         super().__init__()
@@ -84,9 +107,14 @@ class PrefixedKeyDict(collections.UserDict):
 
 
 class KeyConstraintDict(collections.UserDict):
+    """
+    A dict implementation with sets of valid and required keys
+
+    :param valid_keys: Set of valid keys
+    :param required_keys: Set of required keys, must be a subset of valid_keys
+    """
 
     class MissingKeys(Exception):
-
         def __init__(self, keys):
             self.keys = keys
 
@@ -98,6 +126,8 @@ class KeyConstraintDict(collections.UserDict):
         self.seen_keys = set()
 
     def __setitem__(self, key, value):
+        """Trying to add an invalid key will raise KeyError
+        """
         if key in self.valid_keys:
             self.seen_keys.add(key)
             self.data[key] = value
@@ -109,12 +139,16 @@ class KeyConstraintDict(collections.UserDict):
         del self.data[key]
 
     def __iter__(self):
+        """Iteration will raise a MissingKeys exception unless all required keys are set
+        """
         if self.missing():
             raise self.MissingKeys(self.missing())
 
         return self.data.__iter__()
 
     def missing(self):
+        """Returns a set of keys that are required but not set
+        """
         return self.required_keys - (self.seen_keys & self.required_keys)
 
 
@@ -125,6 +159,12 @@ def convert_position(pos, json):
 
 
 def flatten(l):
+    """
+    Flattens a hierarchy of nested lists into a single list containing all elements in order
+
+    :param l: list of arbitrary types and lists
+    :returns: list of arbitrary types
+    """
     l = list(l)
     i = 0
     while i < len(l):
@@ -153,7 +193,11 @@ def formatp(string, **kwargs):
     thus equivalent to a logical or of all enclosing groups with the enclosed
     group.
 
-    Escaped brackets, i.e. \[ and \] are copied verbatim to output.
+    Escaped brackets, i.e. \\[ and \\] are copied verbatim to output.
+
+    :param string: Format string
+    :param **kwargs: keyword arguments providing data for the format string
+    :returns: Formatted string
     """
 
     def build_stack(string):
@@ -166,27 +210,16 @@ def formatp(string, **kwargs):
         class Token:
             string = ""
 
-            def __repr__(self):
-                return "<%s> " % self.__class__.__name__
-
         class OpeningBracket(Token):
-
-            def __repr__(self):
-                return "<Group>"
+            pass
 
         class ClosingBracket(Token):
-
-            def __repr__(self):
-                return "</Group>"
+            pass
 
         class String(Token):
-
             def __init__(self, str):
                 self.string = str
 
-            def __repr__(self):
-                return super().__repr__() + repr(self.string)
-
         TOKENS = {
             "[": OpeningBracket,
             "]": ClosingBracket,
@@ -224,7 +257,6 @@ def formatp(string, **kwargs):
                     token = String(char)
                     token.level = level
                     stack.append(token)
-
         return stack
 
     def build_tree(items, level=0):
@@ -248,7 +280,7 @@ def formatp(string, **kwargs):
                 if level == 0:
                     subtree.append(string.format(**kwargs))
                 else:
-                    fields = formatp.field_re.findall(string)
+                    fields = re.findall(r"({(\w+)[^}]*})", string)
                     successful_fields = 0
                     for fieldspec, fieldname in fields:
                         if kwargs.get(fieldname, False):
@@ -266,10 +298,24 @@ def formatp(string, **kwargs):
     tree = build_tree(stack, 0)
     return merge_tree(tree)
 
-formatp.field_re = re.compile(r"({(\w+)[^}]*})")
-
 
 class TimeWrapper:
+    """
+    A wrapper that implements __format__ and __bool__ for time differences and time spans.
+
+    :param seconds: seconds (numeric)
+    :param default_format: the default format to be used if no explicit format_spec is passed to __format__
+
+    Format string syntax:
+
+    * %h, %m and %s are the hours, minutes and seconds without leading zeros (i.e. 0 to 59 for minutes and seconds)
+    * %H, %M and %S are padded with a leading zero to two digits, i.e. 00 to 59
+    * %l and %L produce hours non-padded and padded but only if hours is not zero. If the hours are zero it produces an empty string.
+    * %% produces a literal %
+    * %E (only valid on beginning of the string) if the time is null, don't format anything but rather produce an empty string. If the time is non-null it is removed from the string.
+
+    The formatted string is stripped, i.e. spaces on both ends of the result are removed
+    """
 
     class TimeTemplate(string.Template):
         delimiter = "%"
@@ -280,9 +326,13 @@ class TimeWrapper:
         self.default_format = default_format
 
     def __bool__(self):
+        """:returns: `bool(seconds)`, i.e. False if seconds == 0 and True otherwise
+        """
         return bool(self.seconds)
 
     def __format__(self, format_spec):
+        """Formats the time span given the format_spec (or the default_format).
+        """
         format_spec = format_spec or self.default_format
         h = self.seconds // 3600
         m, s = divmod(self.seconds % 3600, 60)
@@ -300,8 +350,36 @@ class TimeWrapper:
         ).strip()
 
 
-def render_json(json):
-    if not json.get("full_text", ""):
-        return ""
+def require(predicate):
+    """
+    Decorator factory for methods requiring a predicate. If the predicate is not fulfilled during a method call, the
+    method call is skipped and None is returned.
 
-    return json["full_text"]
+    :param predicate: A callable returning a truth value
+    :returns: Method decorator
+
+    .. seealso::
+
+        :py:func:`internet`
+    """
+    def decorator(method):
+        @functools.wraps(method)
+        def wrapper(*args, **kwargs):
+            if predicate():
+                return method(*args, **kwargs)
+            return None
+        return wrapper
+    return decorator
+
+
+def internet():
+    """
+    Checks for a internet connection by connecting to 8.8.8.8 (Google DNS)
+
+    :returns: True if internet connection is available
+    """
+    try:
+        socket.create_connection(("8.8.8.8", 53), 1).close()
+        return True
+    except OSError:
+        return False
